@@ -25,7 +25,7 @@ my $synth = Synth::Config->new(
 #    verbose => 1,
 );
 
-my $patches = $opt{patch} ? $opt{patch}->@* : $synth->recall_names;
+my $patches = $opt{patch} ? $opt{patch}->@* : $synth->recall_setting_names;
 
 for my $patch_name (@$patches) {
     my $settings = $synth->search_settings(name => $patch_name);
